@@ -11,35 +11,58 @@ import redis
 from redis.commands.json.path import Path
 
 from test import testtools
+from test.testtools import resp_conversion, get_protocol_version
 
 json_tests = pytest.importorskip("jsonpath_ng")
 
 
+def test_jsonsetnx(r: redis.Redis):
+    key = "test_key"
+    assert r.json().set("test_key", "$", {}, nx=True, decode_keys=True) is True
+    assert r.json().set(key, "$.group", {}, nx=True) is True
+    assert r.json().set("test_key", "$.group", {"data": "value"}, nx=True) is None
+
+
 def test_jsonget(r: redis.Redis):
-    data = {'x': "bar", 'y': {'x': 33}}
+    data = {"x": "bar", "y": {"x": 33}}
     r.json().set("foo", Path.root_path(), data)
     assert r.json().get("foo") == data
-    assert r.json().get("foo", Path("$..x")) == ['bar', 33]
+    assert r.json().get("foo", Path("$..x")) == ["bar", 33]
 
-    data2 = {'x': "bar"}
-    r.json().set("foo2", Path.root_path(), data2, )
+    data2 = {"x": "bar"}
+    r.json().set(
+        "foo2",
+        Path.root_path(),
+        data2,
+    )
     assert r.json().get("foo2") == data2
-    assert r.json().get("foo2", "$") == [data2, ]
-    assert r.json().get("foo2", Path("$.a"), Path("$.x")) == {'$.a': [], '$.x': ['bar']}
+    assert r.json().get("foo2", "$") == [
+        data2,
+    ]
+    assert r.json().get("foo2", Path("$.a"), Path("$.x")) == {"$.a": [], "$.x": ["bar"]}
 
     assert r.json().get("non-existing-key") is None
 
-    r.json().set("foo2", Path.root_path(), {'x': "bar", 'y': {'x': 33}}, )
-    assert r.json().get("foo2") == {'x': "bar", 'y': {'x': 33}}
-    assert r.json().get("foo2", Path("$..x")) == ['bar', 33]
+    r.json().set(
+        "foo2",
+        Path.root_path(),
+        {"x": "bar", "y": {"x": 33}},
+    )
+    assert r.json().get("foo2") == {"x": "bar", "y": {"x": 33}}
+    assert r.json().get("foo2", Path("$..x")) == ["bar", 33]
 
-    r.json().set("foo", Path.root_path(), {'x': "bar"}, )
-    assert r.json().get("foo") == {'x': "bar"}
-    assert r.json().get("foo", Path("$.a"), Path("$.x")) == {'$.a': [], '$.x': ['bar']}
+    r.json().set(
+        "foo",
+        Path.root_path(),
+        {"x": "bar"},
+    )
+    assert r.json().get("foo") == {"x": "bar"}
+    assert r.json().get("foo", Path("$.a"), Path("$.x")) == {"$.a": [], "$.x": ["bar"]}
+    assert r.json().get("unknown", "$") is None
 
 
 def test_json_setgetdeleteforget(r: redis.Redis):
-    data = {'x': "bar"}
+    data = {"x": "bar"}
     assert r.json().set("foo", Path.root_path(), data) == 1
     assert r.json().get("foo") == data
     assert r.json().get("baz") is None
@@ -59,25 +82,35 @@ def test_json_delete_with_dollar(r: redis.Redis):
     assert r.json().delete("doc2", "$..a") == 1
     assert r.json().get("doc2", Path.root_path()) == {"nested": {"b": [True, "a", "b"]}, "b": ["a", "b"]}
 
-    doc3 = [{
-        "ciao": ["non ancora"],
-        "nested": [
-            {"ciao": [1, "a"]},
-            {"ciao": [2, "a"]},
-            {"ciaoc": [3, "non", "ciao"]},
-            {"ciao": [4, "a"]},
-            {"e": [5, "non", "ciao"]},
-        ],
-    }]
+    doc3 = [
+        {
+            "ciao": ["non ancora"],
+            "nested": [
+                {"ciao": [1, "a"]},
+                {"ciao": [2, "a"]},
+                {"ciaoc": [3, "non", "ciao"]},
+                {"ciao": [4, "a"]},
+                {"e": [5, "non", "ciao"]},
+            ],
+        }
+    ]
     assert r.json().set("doc3", Path.root_path(), doc3)
     assert r.json().delete("doc3", '$.[0]["nested"]..ciao') == 3
 
-    doc3val = [[{
-        "ciao": ["non ancora"],
-        "nested": [
-            {}, {}, {"ciaoc": [3, "non", "ciao"]}, {}, {"e": [5, "non", "ciao"]},
-        ],
-    }]]
+    doc3val = [
+        [
+            {
+                "ciao": ["non ancora"],
+                "nested": [
+                    {},
+                    {},
+                    {"ciaoc": [3, "non", "ciao"]},
+                    {},
+                    {"e": [5, "non", "ciao"]},
+                ],
+            }
+        ]
+    ]
     assert r.json().get("doc3", Path.root_path()) == doc3val[0]
 
     # Test default path
@@ -88,14 +121,18 @@ def test_json_delete_with_dollar(r: redis.Redis):
 
 
 def test_json_et_non_dict_value(r: redis.Redis):
-    r.json().set("str", Path.root_path(), 'str_val', )
-    assert r.json().get('str') == 'str_val'
+    r.json().set(
+        "str",
+        Path.root_path(),
+        "str_val",
+    )
+    assert r.json().get("str") == "str_val"
 
     r.json().set("bool", Path.root_path(), True)
-    assert r.json().get('bool') is True
+    assert r.json().get("bool") is True
 
     r.json().set("bool", Path.root_path(), False)
-    assert r.json().get('bool') is False
+    assert r.json().get("bool") is False
 
 
 def test_jsonset_existential_modifiers_should_succeed(r: redis.Redis):
@@ -103,10 +140,26 @@ def test_jsonset_existential_modifiers_should_succeed(r: redis.Redis):
     assert r.json().set("obj", Path.root_path(), obj)
 
     # Test that flags prevent updates when conditions are unmet
-    assert r.json().set("obj", Path("foo"), "baz", nx=True, ) is None
+    assert (
+        r.json().set(
+            "obj",
+            Path("foo"),
+            "baz",
+            nx=True,
+        )
+        is None
+    )
     assert r.json().get("obj") == obj
 
-    assert r.json().set("obj", Path("qaz"), "baz", xx=True, ) is None
+    assert (
+        r.json().set(
+            "obj",
+            Path("qaz"),
+            "baz",
+            xx=True,
+        )
+        is None
+    )
     assert r.json().get("obj") == obj
 
     # Test that flags allow updates when conditions are met
@@ -116,20 +169,20 @@ def test_jsonset_existential_modifiers_should_succeed(r: redis.Redis):
 
     # Test with raw
     obj = {"foo": "bar"}
-    testtools.raw_command(r, 'json.set', 'obj', '$', json.dumps(obj))
-    assert r.json().get('obj') == obj
+    testtools.raw_command(r, "json.set", "obj", "$", json.dumps(obj))
+    assert r.json().get("obj") == obj
 
 
 def test_jsonset_flags_should_be_mutually_exclusive(r: redis.Redis):
     with pytest.raises(Exception):
         r.json().set("obj", Path("foo"), "baz", nx=True, xx=True)
     with pytest.raises(redis.ResponseError):
-        testtools.raw_command(r, 'json.set', 'obj', '$', json.dumps({"foo": "bar"}), 'NX', 'XX')
+        testtools.raw_command(r, "json.set", "obj", "$", json.dumps({"foo": "bar"}), "NX", "XX")
 
 
 def test_json_unknown_param(r: redis.Redis):
     with pytest.raises(redis.ResponseError):
-        testtools.raw_command(r, 'json.set', 'obj', '$', json.dumps({"foo": "bar"}), 'unknown')
+        testtools.raw_command(r, "json.set", "obj", "$", json.dumps({"foo": "bar"}), "unknown")
 
 
 def test_jsonmget(r: redis.Redis):
@@ -164,9 +217,16 @@ def test_jsonmget_should_succeed(r: redis.Redis):
 
 
 def test_jsonclear(r: redis.Redis):
-    r.json().set("arr", Path.root_path(), [0, 1, 2, 3, 4], )
+    r.json().set(
+        "arr",
+        Path.root_path(),
+        [0, 1, 2, 3, 4],
+    )
 
-    assert 1 == r.json().clear("arr", Path.root_path(), )
+    assert 1 == r.json().clear(
+        "arr",
+        Path.root_path(),
+    )
     assert [] == r.json().get("arr")
 
 
@@ -175,7 +235,7 @@ def test_jsonclear_dollar(r: redis.Redis):
         "nested1": {"a": {"foo": 10, "bar": 20}},
         "a": ["foo"],
         "nested2": {"a": "claro"},
-        "nested3": {"a": {"baz": 50}}
+        "nested3": {"a": {"baz": 50}},
     }
     r.json().set("doc1", "$", data)
     # Test multi
@@ -209,18 +269,18 @@ def test_jsonclear_no_doc(r: redis.Redis):
 
 
 def test_jsonstrlen(r: redis.Redis):
-    data = {'x': "bar", 'y': {'x': 33}}
+    data = {"x": "bar", "y": {"x": 33}}
     r.json().set("foo", Path.root_path(), data)
     assert r.json().strlen("foo", Path("$..x")) == [3, None]
 
     r.json().set("foo2", Path.root_path(), "data2")
-    assert r.json().strlen('foo2') == 5
-    assert r.json().strlen('foo2', Path.root_path()) == 5
+    assert r.json().strlen("foo2") == 5
+    assert r.json().strlen("foo2", Path.root_path()) == 5
 
-    r.json().set("foo3", Path.root_path(), {'x': 'string'})
-    assert r.json().strlen("foo3", Path("$.x")) == [6, ]
+    r.json().set("foo3", Path.root_path(), {"x": "string"})
+    assert r.json().strlen("foo3", Path("$.x")) == [6]
 
-    assert r.json().strlen('non-existing') is None
+    assert r.json().strlen("non-existing") is None
 
     r.json().set("str", Path.root_path(), "foo")
     assert r.json().strlen("str", Path.root_path()) == 3
@@ -237,9 +297,11 @@ def test_jsonstrlen(r: redis.Redis):
     assert r.json().strlen("doc1", "$.nested2.a") == [None]
 
     # Test missing key
-    with pytest.raises(redis.ResponseError):
+    with pytest.raises(redis.ResponseError) as ctx:
         r.json().strlen("non_existing_doc", "$..a")
 
+    assert str(ctx.value) == "could not perform this operation on a key that doesn't exist"
+
 
 def test_toggle(r: redis.Redis):
     r.json().set("bool", Path.root_path(), False)
@@ -262,8 +324,8 @@ def test_toggle_dollar(r: redis.Redis):
     r.json().set("doc1", "$", data)
     # Test multi
     assert r.json().toggle("doc1", "$..a") == [None, 1, None, 0]
-    data['nested1']['a'] = True
-    data['nested3']['a'] = False
+    data["nested1"]["a"] = True
+    data["nested3"]["a"] = False
     assert r.json().get("doc1", "$") == [data]
 
     # Test missing key
@@ -304,31 +366,71 @@ def test_strappend(r: redis.Redis):
     assert "foobar" == r.json().get("json-key", Path.root_path())
 
     # Test multi
-    r.json().set("doc1", Path.root_path(), {"a": "foo", "nested1": {"a": "hello"}, "nested2": {"a": 31}, })
+    r.json().set(
+        "doc1",
+        Path.root_path(),
+        {
+            "a": "foo",
+            "nested1": {"a": "hello"},
+            "nested2": {"a": 31},
+        },
+    )
     assert r.json().strappend("doc1", "bar", "$..a") == [6, 8, None]
-    assert r.json().get("doc1") == {"a": "foobar", "nested1": {"a": "hellobar"}, "nested2": {"a": 31}, }
+    assert r.json().get("doc1") == {
+        "a": "foobar",
+        "nested1": {"a": "hellobar"},
+        "nested2": {"a": 31},
+    }
 
     # Test single
-    assert r.json().strappend("doc1", "baz", "$.nested1.a", ) == [11]
-    assert r.json().get("doc1") == {"a": "foobar", "nested1": {"a": "hellobarbaz"}, "nested2": {"a": 31}, }
+    assert r.json().strappend(
+        "doc1",
+        "baz",
+        "$.nested1.a",
+    ) == [11]
+    assert r.json().get("doc1") == {
+        "a": "foobar",
+        "nested1": {"a": "hellobarbaz"},
+        "nested2": {"a": 31},
+    }
 
     # Test missing key
     with pytest.raises(redis.exceptions.ResponseError):
         r.json().strappend("non_existing_doc", "$..a", "err")
 
     # Test multi
-    r.json().set("doc2", Path.root_path(), {"a": "foo", "nested1": {"a": "hello"}, "nested2": {"a": "hi"}, })
+    r.json().set(
+        "doc2",
+        Path.root_path(),
+        {
+            "a": "foo",
+            "nested1": {"a": "hello"},
+            "nested2": {"a": "hi"},
+        },
+    )
     assert r.json().strappend("doc2", "bar", "$.*.a") == [8, 5]
-    assert r.json().get("doc2") == {"a": "foo", "nested1": {"a": "hellobar"}, "nested2": {"a": "hibar"}, }
+    assert r.json().get("doc2") == {
+        "a": "foo",
+        "nested1": {"a": "hellobar"},
+        "nested2": {"a": "hibar"},
+    }
 
     # Test missing path
-    r.json().set("doc1", Path.root_path(), {"a": "foo", "nested1": {"a": "hello"}, "nested2": {"a": 31}, })
+    r.json().set(
+        "doc1",
+        Path.root_path(),
+        {
+            "a": "foo",
+            "nested1": {"a": "hello"},
+            "nested2": {"a": 31},
+        },
+    )
     with pytest.raises(redis.exceptions.ResponseError):
         r.json().strappend("doc1", "add", "piu")
 
     # Test raw command with no arguments
     with pytest.raises(redis.ResponseError):
-        testtools.raw_command(r, 'json.strappend', '')
+        testtools.raw_command(r, "json.strappend", "")
 
 
 @pytest.mark.decode_responses(True)
@@ -341,7 +443,7 @@ def test_decode_response_disabaled_null(r: redis.Redis):
 
 
 def test_json_get_jset(r: redis.Redis):
-    assert r.json().set("foo", Path.root_path(), "bar", ) == 1
+    assert r.json().set("foo", Path.root_path(), "bar") == 1
     assert "bar" == r.json().get("foo")
     assert r.json().get("baz") is None
     assert 1 == r.json().delete("foo")
@@ -349,8 +451,15 @@ def test_json_get_jset(r: redis.Redis):
 
 
 def test_nonascii_setgetdelete(r: redis.Redis):
-    assert r.json().set("not-ascii", Path.root_path(), "hyvää-élève", )
-    assert "hyvää-élève" == r.json().get("not-ascii", no_escape=True, )
+    assert r.json().set(
+        "not-ascii",
+        Path.root_path(),
+        "hyvää-élève",
+    )
+    assert "hyvää-élève" == r.json().get(
+        "not-ascii",
+        no_escape=True,
+    )
     assert 1 == r.json().delete("not-ascii")
     assert r.exists("not-ascii") == 0
 
@@ -400,25 +509,43 @@ def test_set_path(r: redis.Redis):
     assert r.json().get(jsonfile.name.rsplit(".")[0]) == {"hello": "world"}
 
 
+@pytest.mark.min_server("7")
 def test_type(r: redis.Redis):
-    r.json().set("1", Path.root_path(), 1, )
+    r.json().set("1", Path.root_path(), 1)
 
-    assert r.json().type("1", Path.root_path(), ) == b"integer"
-    assert r.json().type("1") == b"integer"
+    assert r.json().type("1", Path.root_path()) == resp_conversion(r, [b"integer"], b"integer")
+    assert r.json().type("1") == resp_conversion(r, [b"integer"], b"integer")  # noqa: E721
 
-    meta_data = {"object": {}, "array": [], "string": "str", "integer": 42, "number": 1.2, "boolean": False,
-                 "null": None, }
-    data = {k: {'a': meta_data[k]} for k in meta_data}
+    meta_data = {
+        "object": {},
+        "array": [],
+        "string": "str",
+        "integer": 42,
+        "number": 1.2,
+        "boolean": False,
+        "null": None,
+    }
+    data = {k: {"a": meta_data[k]} for k in meta_data}
     r.json().set("doc1", "$", data)
     # Test multi
-    assert r.json().type("doc1", "$..a") == [k.encode() for k in meta_data.keys()]
+    values = r.json().get("doc1", "$..a")
+    expected = []
+    for v in values:
+        for k, val in meta_data.items():
+            if v == val:
+                expected.append(k.encode())
+                break
+    assert r.json().type("doc1", "$..a") == resp_conversion(r, [expected], expected)  # noqa: E721
 
     # Test single
-    assert r.json().type("doc1", "$.integer.a") == [b'integer']
-    assert r.json().type("doc1") == b'object'
+    assert r.json().type("doc1", "$.integer.a") == resp_conversion(r, [[b"integer"]], [b"integer"])
+    assert r.json().type("doc1") == resp_conversion(r, [b"object"], b"object")
 
     # Test missing key
-    assert r.json().type("non_existing_doc", "..a") is None
+    if get_protocol_version(r) == 2:
+        assert r.json().type("non_existing_doc", "..a") is None
+    else:
+        assert r.json().type("non_existing_doc", "..a") == [None]
 
 
 def test_objlen(r: redis.Redis):
@@ -428,16 +555,20 @@ def test_objlen(r: redis.Redis):
 
     obj = {"foo": "bar", "baz": "qaz"}
 
-    r.json().set("obj", Path.root_path(), obj, )
-    assert len(obj) == r.json().objlen("obj", Path.root_path(), )
+    r.json().set("obj", Path.root_path(), obj)
+    assert len(obj) == r.json().objlen("obj", Path.root_path())
 
     r.json().set("obj", Path.root_path(), obj)
     assert len(obj) == r.json().objlen("obj")
-    r.json().set("doc1", "$", {
-        "a": ["foo"],
-        "nested1": {"a": {"foo": 10, "bar": 20}},
-        "nested2": {"a": {"baz": 50}},
-    })
+    r.json().set(
+        "doc1",
+        "$",
+        {
+            "a": ["foo"],
+            "nested1": {"a": {"foo": 10, "bar": 20}},
+            "nested2": {"a": {"baz": 50}},
+        },
+    )
     # Test multi
     assert r.json().objlen("doc1", "$..a") == [None, 2, 1]
     # Test single
@@ -464,12 +595,12 @@ def test_objkeys(r: redis.Redis):
     r.json().set("obj", Path.root_path(), obj)
     keys = r.json().objkeys("obj", Path.root_path())
     keys.sort()
-    exp = list(obj.keys())
+    exp = [k.encode() for k in obj.keys()]
     exp.sort()
-    assert exp == keys
+    assert set(keys) == resp_conversion(r, {k.encode() for k in obj.keys()}, set(obj.keys()))
 
     r.json().set("obj", Path.root_path(), obj)
-    assert r.json().objkeys("obj") == list(obj.keys())
+    assert set(r.json().objkeys("obj")) == resp_conversion(r, {k.encode() for k in obj.keys()}, set(obj.keys()))
 
     assert r.json().objkeys("fakekey") is None
 
@@ -484,12 +615,15 @@ def test_objkeys(r: redis.Redis):
     )
 
     # Test single
-    assert r.json().objkeys("doc1", "$.nested1.a") == [[b"foo", b"bar"]]
+    keys = r.json().objkeys("doc1", "$.nested1.a")
+    assert isinstance(keys, list)
+    assert isinstance(keys[0], list)
+    assert set(keys[0]) == {b"foo", b"bar"}
 
     # Test legacy
-    assert r.json().objkeys("doc1", ".*.a") == ["foo", "bar"]
+    assert set(r.json().objkeys("doc1", ".*.a")) == resp_conversion(r, {b"foo", b"bar"}, {"foo", "bar"})
     # Test single
-    assert r.json().objkeys("doc1", ".nested2.a") == ["baz"]
+    assert r.json().objkeys("doc1", ".nested2.a") == resp_conversion(r, [b"baz"], ["baz"])
 
     # Test missing key
     assert r.json().objkeys("non_existing_doc", "..a") is None
@@ -501,12 +635,13 @@ def test_objkeys(r: redis.Redis):
     assert r.json().objkeys("doc1", "$..nowhere") == []
 
 
+@pytest.mark.min_server("7")
 def test_numincrby(r: redis.Redis):
     r.json().set("num", Path.root_path(), 1)
 
-    assert 2 == r.json().numincrby("num", Path.root_path(), 1)
-    assert 2.5 == r.json().numincrby("num", Path.root_path(), 0.5)
-    assert 1.25 == r.json().numincrby("num", Path.root_path(), -1.25)
+    assert r.json().numincrby("num", Path.root_path(), 1) == resp_conversion(r, [2], 2)
+    assert r.json().numincrby("num", Path.root_path(), 0.5) == resp_conversion(r, [2.5], 2.5)
+    assert r.json().numincrby("num", Path.root_path(), -1.25) == resp_conversion(r, [1.25], 1.25)
     # Test NUMINCRBY
     r.json().set("doc1", "$", {"a": "b", "b": [{"a": 2}, {"a": 5.0}, {"a": "c"}]})
     # Test multi
@@ -520,13 +655,14 @@ def test_numincrby(r: redis.Redis):
     assert r.json().numincrby("doc1", "$.b[1].a", 3.5) == [15.0]
 
 
+@pytest.mark.min_server("7")
 def test_nummultby(r: redis.Redis):
     r.json().set("num", Path.root_path(), 1)
 
     with pytest.deprecated_call():
-        assert r.json().nummultby("num", Path.root_path(), 2) == 2
-        assert r.json().nummultby("num", Path.root_path(), 2.5) == 5
-        assert r.json().nummultby("num", Path.root_path(), 0.5) == 2.5
+        assert r.json().nummultby("num", Path.root_path(), 2) == resp_conversion(r, [2], 2)
+        assert r.json().nummultby("num", Path.root_path(), 2.5) == resp_conversion(r, [5], 5)
+        assert r.json().nummultby("num", Path.root_path(), 0.5) == resp_conversion(r, [2.5], 2.5)
 
     r.json().set("doc1", "$", {"a": "b", "b": [{"a": 2}, {"a": 5.0}, {"a": "c"}]})
 
@@ -548,36 +684,42 @@ def test_nummultby(r: redis.Redis):
 
     # Test legacy NUMINCRBY
     r.json().set("doc1", "$", {"a": "b", "b": [{"a": 2}, {"a": 5.0}, {"a": "c"}]})
-    assert r.json().numincrby("doc1", ".b[0].a", 3) == 5
+    assert r.json().numincrby("doc1", ".b[0].a", 3) == resp_conversion(r, [5], 5)
 
     # Test legacy NUMMULTBY
     r.json().set("doc1", "$", {"a": "b", "b": [{"a": 2}, {"a": 5.0}, {"a": "c"}]})
 
     with pytest.deprecated_call():
-        assert r.json().nummultby("doc1", ".b[0].a", 3) == 6
+        assert r.json().nummultby("doc1", ".b[0].a", 3) == resp_conversion(r, [6], 6)
 
 
-@testtools.run_test_if_redispy_ver('above', '5')
+@testtools.run_test_if_redispy_ver("gte", "4.6")
+@pytest.mark.min_server("7.1")
 def test_json_merge(r: redis.Redis):
     # Test with root path $
-    key = "person_data"
-    r.json().set(key, Path.root_path(), {"person1": {"personal_data": {"name": "John"}}}, )
-    r.json().merge(key, Path.root_path(), {"person1": {"personal_data": {"hobbies": "reading"}}})
-    assert r.json().get(key) == {"person1": {"personal_data": {"name": "John", "hobbies": "reading"}}}
+    assert r.json().set(
+        "person_data",
+        "$",
+        {"person1": {"personal_data": {"name": "John"}}},
+    )
+    assert r.json().merge("person_data", "$", {"person1": {"personal_data": {"hobbies": "reading"}}})
+    assert r.json().get("person_data") == {"person1": {"personal_data": {"name": "John", "hobbies": "reading"}}}
 
     # Test with root path path $.person1.personal_data
-    r.json().merge(key, "$.person1.personal_data", {"country": "Israel"})
-    assert r.json().get(key) == {
-        "person1": {"personal_data": {"name": "John", "hobbies": "reading", "country": "Israel"}}}
+    assert r.json().merge("person_data", "$.person1.personal_data", {"country": "Israel"})
+    assert r.json().get("person_data") == {
+        "person1": {"personal_data": {"name": "John", "hobbies": "reading", "country": "Israel"}}
+    }
 
     # Test with null value to delete a value
-    r.json().merge("person_data", "$.person1.personal_data", {"name": None})
-    assert r.json().get(key) == {"person1": {"personal_data": {"country": "Israel", "hobbies": "reading"}}}
+    assert r.json().merge("person_data", "$.person1.personal_data", {"name": None})
+    assert r.json().get("person_data") == {"person1": {"personal_data": {"country": "Israel", "hobbies": "reading"}}}
 
 
-@testtools.run_test_if_redispy_ver('above', '5')
+@testtools.run_test_if_redispy_ver("gte", "4.6")
+@pytest.mark.min_server("7.1")
 def test_mset(r: redis.Redis):
-    r.json().mset("1", Path.root_path(), 1, "2", Path.root_path(), 2)
+    r.json().mset([("1", Path.root_path(), 1), ("2", Path.root_path(), 2)])
 
     assert r.json().mget(["1"], Path.root_path()) == [1]
     assert r.json().mget(["1", "2"], Path.root_path()) == [1, 2]
